@@ -1,7 +1,7 @@
 package HTML::FormHandler::Widget::Field::Checkbox;
 
 use Moose::Role;
-use HTML::Entities;
+with 'HTML::FormHandler::Widget::Field::Role::HTMLAttributes';
 
 sub render {
     my ( $self, $result ) = @_;
@@ -10,8 +10,9 @@ sub render {
     my $fif    = $result->fif;
     my $output = '<input type="checkbox" name="';
     $output .= $self->html_name . '" id="' . $self->id . '"';
-    $output .= ' value="' . encode_entities($self->checkbox_value) . '"';
+    $output .= ' value="' . $self->html_filter($self->checkbox_value) . '"';
     $output .= ' checked="checked"' if $fif eq $self->checkbox_value;
+    $output .= $self->_add_html_attributes;
     $output .= ' />';
     return $self->wrap_field( $result, $output );
 }
