@@ -2,6 +2,12 @@ package HTML::FormHandler::Widget::Field::CheckboxGroup;
 
 use Moose::Role;
 
+with 'HTML::FormHandler::Widget::Field::Role::SelectedOption';
+with 'HTML::FormHandler::Widget::Field::Role::HTMLAttributes';
+
+has 'input_without_param' => ( is => 'ro', default => sub {[]} );
+has 'not_nullable' => ( is => 'ro', default => 1 );
+
 sub render {
     my ( $self, $result ) = @_;
 
@@ -22,14 +28,17 @@ sub render {
                 }
                 foreach my $optval (@fif) {
                     $output .= ' checked="checked"'
-                        if $optval == $option->{value};
+                        if $self->check_selected_option($option, $optval);
                 }
             }
             else {
                 $output .= ' checked="checked"'
-                    if $option->{value} eq $ffif;
+                    if $self->check_selected_option($option, $ffif);
             }
         }
+        $output .= ' checked="checked"'
+            if $self->check_selected_option($option);
+        $output .= $self->_add_html_attributes;
         $output .= ' />';
         $output .= $option->{label} . '<br />';
         $index++;
